@@ -121,6 +121,7 @@ impl CashFlowType {
         for &fee_description in &[
             "Комиссия за ведение учета ЦБ",
             "Ежегодная комиссия за ведение учета ЦБ",
+            "Проценты за предоставление займа ДС Брокером",
             "Комиссия за предоставление информации Брокером по ЦБ",
             "Минимальная комиссия Брокера за обработку поручений и предоставление информации",
             "Вознаграждение Брокера за обработку заявления на вывод безналичных денежных средств",
@@ -134,7 +135,8 @@ impl CashFlowType {
         lazy_static! {
             static ref DIVIDEND_REGEXES: Vec<Regex> = [
                 r"^Выплата дохода клиент [^ ]+ дивиденды (?P<issuer>[^,]+), комиссия платежного агента",
-                r"^Выплата дохода клиент [^ ]+ дивиденды (?P<issuer>.+) налог к удержанию",
+                r"^Выплата дохода клиент [^ ]+ дивиденды (?P<issuer>[^,]+) налог к удержанию",
+                r"^Выплата дохода клиент [^ ]+ дивиденды (?P<issuer>[^,]+)$"
             ].iter().map(|regex| Regex::new(regex).unwrap()).collect();
         }
 
@@ -194,6 +196,8 @@ mod tests {
              "Комиссия за ведение учета ЦБ"),
         case("Ежегодная комиссия за ведение учета ЦБ в НКО АО НРД за 2017 г.",
              "Ежегодная комиссия за ведение учета ЦБ"),
+        case("Проценты за предоставление займа ДС Брокером на ФР МБ, остаток в рублях -43.57",
+             "Проценты за предоставление займа ДС Брокером"),
         case("Комиссия за предоставление информации Брокером по ЦБ по месту хранения НКО АО НРД за апрель, 2018 г.",
              "Комиссия за предоставление информации Брокером по ЦБ"),
         case("Минимальная комиссия Брокера за обработку поручений и предоставление информации за июль 2017 клиент 123456",
@@ -219,6 +223,8 @@ mod tests {
              "ГАЗПРОМ-ао-2"),
         case("Выплата дохода клиент 123456 дивиденды Татнфт 3ап налог к удержанию 13.00 рублей",
              "Татнфт 3ап"),
+        case("Выплата дохода клиент 123456 дивиденды ROS AGRO PLC-GDR",
+             "ROS AGRO PLC-GDR"),
     )]
     fn dividend_description_parsing(description: &str, expected: &str) {
         assert_matches!(
